@@ -1,7 +1,9 @@
 # -*- coding: utf-8 -*-
 import json
+from django.conf import settings
 from django.http import HttpResponse
 from django_zotero.models import ItemType, Field
+from os.path import abspath, dirname, join, pardir
 
 
 def itemtype_fields_view(request):
@@ -13,6 +15,24 @@ def itemtype_fields_view(request):
     return HttpResponse(json_fields, content_type='text/javascript')
 
 
+def valid_zotero_itemtypes_fields(request):
+    path = abspath(
+        join(dirname(__file__),
+        'media/valid_zotero_itemtypes_and_fields.txt'))
+    itemtypes_fields = {}
+    for line in open(path):
+        if line and not line.startswith('#'):
+            line = line.strip()
+            itemtype = line.split(':')[0]
+            fields = line.split(':')[1]
+            fields = fields.split(',')
+            itemtype_id = ItemType.objects.get(type_name=itemtype).id
+            field_ids = [Field.objects.get(field_name=field).id for field in fields]
+            itemtypes_fields[itemtype_id] = field_ids
+    json_itemtypes_fields = json.dumps(itemtypes_fields)
+    return HttpResponse(json_itemtypes_fields, content_type='text/javascript')
+
+
 #test
 from django.shortcuts import render
 from django_zotero.forms import DocumentForm, get_tag_formset
